# Generated by Django 2.1.5 on 2019-10-17 17:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('chibi_user', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='user',
            name='id',
            field=models.CharField(max_length=64, primary_key=True, serialize=False, verbose_name='Id'),
        ),
    ]
